<?php
/*
 * Theme Setup
 *
 * @package zoom
 * @subpackage Functions
*/

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @since 1.0
 */
 
/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since 1.0
 */
if ( ! isset( $content_width ) ) {
	$content_width = get_theme_mod( 'site_maxwidth', '1200' ).'px';
}
 
function zoom_theme_setup() {
	
	/**
	 * This theme styles the visual editor with editor-style.css to match the theme style.
	 */
	add_editor_style( 'inc/assets/css/editor-style.css' );
	
	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 */
	load_theme_textdomain( 'zoom-lite', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );
	
	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/**
	 * Enable support for Post Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	/**
	 * Add support for background color and images
	 */
	add_theme_support( 'custom-background', array(
		'default-color' => '3f3f3f',
	) );
	
	/**
	 * Add support for HeaderCustom Logo
	 */
	add_theme_support( 'custom-logo', array(
		'height'      => 200,
		'width'       => 200,
		'flex-width' => true,
		'flex-height' => true,
	) );
	
	/**
	 * Filter Zoom Lite custom-header support arguments.
	 */
	add_theme_support( 'custom-header', apply_filters( 'zoom_lite_custom_header_args', array(
		'default-image'      => get_template_directory_uri().'/assets/images/header/default.jpg',
		'width'              => 1200,
		'header-text'        => false,
		'height'             => 350,
		'flex-height'        => true,
	) ) );

	register_default_headers( array(
		'default-image' => array(
			'url'           => '%s/assets/images/header/default.jpg',
			'thumbnail_url' => '%s/assets/images/header/default.jpg',
			'description'   => esc_html__( 'Default Header Image', 'zoom-lite' ),
		),
	) );	

	/**
	 * Add image sizes
	 */
	 
    // Thumbnail sizes
	add_image_size( 'zoom-img-thumbnail', 200, 200, true );
    add_image_size( 'zoom-img-medium', 320, 320, true );
    add_image_size( 'zoom-img-mlarge', 520, 245, true );
    add_image_size( 'zoom-img-large', 720, 340, true );
	
	// Slider
	add_image_size( 'zoom-img-slider', 1200 ); // No Hard Crop
	
	// Set the default Featured Image (formerly Post Thumbnail) dimensions.
	 set_post_thumbnail_size( 200, 200, array( 'center', 'center')  );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'zoom-lite' ),
	) );
	
	// Make theme woocommerce ready
	add_theme_support( 'woocommerce' );
	
	
// About Page(

	require_once get_template_directory() . '/inc/zoom-about-page/class-zoom-about-page.php';

	/*
	* About page instance
	*/
	$config = array(
		// Menu name under Appearance.
		'menu_name'               => __( 'About Zoom Lite', 'zoom-lite' ),
		// Page title.
		'page_name'               => __( 'About Zoom Lite', 'zoom-lite' ),
		// Main welcome title
		'welcome_title'         => sprintf( __( 'Welcome to %s', 'zoom-lite' ), 'Zoom Lite' ),
		// Main welcome content
		'welcome_content'       => esc_html__( 'Zoom Lite is a free WordPress theme. It\'s perfect for blogs, personal, photography sites or freelancer. Zoom Lite is 100% responsive, clean, modern, flat and minimal. Zoom Lite is ecommerce (WooCommerce) Compatible, WPML, RTL and also SEO Friendly.', 'zoom-lite' ),
		/**
		 * Tabs array.
		 *
		 * The key needs to be ONLY consisted from letters and underscores. If we want to define outside the class a function to render the tab,
		 * the will be the name of the function which will be used to render the tab content.
		 */
		'tabs'                    => array(
			'getting_started'  => __( 'Getting Started', 'zoom-lite' ),
			'recommended_actions' => __( 'Recommended Actions', 'zoom-lite' ),
			'recommended_plugins' => __( 'Useful Plugins','zoom-lite' ),
			'support'       => __( 'Support', 'zoom-lite' ),
			//'changelog'        => __( 'Changelog', 'zoom-lite' ),
		),
		// Support content tab.
		'support_content'      => array(
			'first' => array (
				'title' => esc_html__( 'Contact Support','zoom-lite' ),
				'icon' => 'dashicons dashicons-sos',
				'text' => esc_html__( 'We want to make sure you have the best experience using Zoom Lite and that is why we gathered here all the necessary informations for you. We hope you will enjoy using Zoom Lite, as much as we enjoy creating great products.','zoom-lite' ),
				'button_label' => esc_html__( 'Contact Support','zoom-lite' ),
				'button_link' => esc_url( 'https://ghozylab.com/plugins/submit-support-request/#tab-1399384216-2-4' ),
				'is_button' => true,
				'is_new_tab' => true
			),
			'second' => array(
				'title' => esc_html__( 'Changelog','zoom-lite' ),
				'icon' => 'dashicons dashicons-portfolio',
				'text' => esc_html__( 'Want to get the gist on the latest theme changes? Just consult our changelog below to get a taste of the recent fixes and features implemented. We recommend you to use the latest version of the theme.','zoom-lite' ),
				'button_label' => esc_html__( 'Changelog','zoom-lite' ),
				'button_link' => esc_url( 'https://themes.trac.wordpress.org/log/zoom-lite/' ),
				'is_button' => true,
				'is_new_tab' => true
			), /*
			'third' => array(
				'title' => esc_html__( 'Documentation','zoom-lite' ),
				'icon' => 'dashicons dashicons-book-alt',
				'text' => esc_html__( 'Need more details? Please check our full documentation for detailed information on how to use Zoom Lite.','zoom-lite' ),
				'button_label' => esc_html__( 'Read full documentation','zoom-lite' ),
				'button_link' => esc_url( 'https://themes.ghozylab.com/zoom' ),
				'is_button' => false,
				'is_new_tab' => true
			), */
		),
		// Getting started tab
		'getting_started' => array(
			'first' => array (
				'title' => esc_html__( 'Recommended actions','zoom-lite' ),
				'text' => esc_html__( 'We have compiled a list of steps for you, to take make sure the experience you will have using one of our products is very easy to follow.','zoom-lite' ),
				'button_label' => esc_html__( 'Recommended actions','zoom-lite' ),
				'button_link' => esc_url( admin_url( 'themes.php?page=zoom-lite-welcome&tab=recommended_actions' ) ),
				'is_button' => true,
				'recommended_actions' => true,
                'is_new_tab' => false
			),
			'second' => array(
				'title' => esc_html__( 'Go to Customizer','zoom-lite' ),
				'text' => esc_html__( 'Using the WordPress Customizer you can easily customize every aspect of the theme. We also provide tons of options that you can use!','zoom-lite' ),
				'button_label' => esc_html__( 'Go to Customizer','zoom-lite' ),
				'button_link' => esc_url( admin_url( 'customize.php' ) ),
				'is_button' => true,
				'recommended_actions' => false,
                'is_new_tab' => false
			), /*
			'third' => array(
				'title' => esc_html__( 'Read full documentation','zoom-lite' ),
				'text' => esc_html__( 'Need more details? Please check our full documentation for detailed information on how to use Zoom Lite.','zoom-lite' ),
				'button_label' => esc_html__( 'Documentation','zoom-lite' ),
				'button_link' => 'https://themes.ghozylab.com/zoom',
				'is_button' => false,
				'recommended_actions' => false,
                'is_new_tab' => true
			) */
		),
		// Plugins array.
		'recommended_plugins'        => array(
			'already_activated_message' => esc_html__( 'Already activated', 'zoom-lite' ),
			'version_label' => esc_html__( 'Version: ', 'zoom-lite' ),
			'install_label' => esc_html__( 'Install', 'zoom-lite' ),
			'activate_label' => esc_html__( 'Activate', 'zoom-lite' ),
			'deactivate_label' => esc_html__( 'Deactivate', 'zoom-lite' ),
			'content'                   => array(
				array(
					'slug' => 'contact-form-lite',
					'file_name' => 'easy-contact-form'
				),
                array(
                    'slug' => 'easy-media-gallery',
					'file_name' => 'easy-media-gallery'
                ),
                array(
                    'slug' => 'feed-instagram-lite',
					'file_name' => 'feed-instagram-lite'
                ),
                array(
                    'slug' => 'icon',
					'file_name' => 'icon'
                ),
                array(
                    'slug' => 'image-slider-widget',
					'file_name' => 'easy-slider-widget-lite'
                ),
                array(
                    'slug' => 'image-carousel',
					'file_name' => 'image-carousel'
                )
			),
		),
		// Required actions array.
		'recommended_actions'        => array(
			'install_label' => esc_html__( 'Install', 'zoom-lite' ),
			'activate_label' => esc_html__( 'Activate', 'zoom-lite' ),
			'deactivate_label' => esc_html__( 'Deactivate', 'zoom-lite' ),
			'content'            => array(
				'easy-media-gallery' => array(
					'title'       => 'Gallery',
					'description' => __( 'Easy Media Gallery is a wordPress plugin designed to display various media support including grid gallery, galleries, photo album, multiple photo albums, portfolio, photo gallery, image slider or image gallery.', 'zoom-lite' ),
					'check'       => defined( 'EASYMEDIA_VERSION' ),
					'plugin_slug' => 'easy-media-gallery',
					'file_name' => 'easy-media-gallery',
					'id' => 'easy-media-gallery'
				),
				'contact-form-lite' => array(
					'title'       => 'Contact Form',
					'description' => __( 'Makes your contact page more engaging by creating a good-looking contact form on your website. The interaction with your visitors was never easier.', 'zoom-lite' ),
					'check'       => defined( 'ECF_VERSION' ),
					'plugin_slug' => 'contact-form-lite',
					'file_name' => 'easy-contact-form',
					'id' => 'contact-form-lite'
				),

			),
		),
	);
	ZOOM_About_Page::init( $config );	
	
	
}
add_action( 'after_setup_theme', 'zoom_theme_setup' );


/**
 * Register widgetized area and update sidebar with default widgets
 *
 * @since 1.0
 */
function zoom_theme_widgets_init() {
	register_sidebar( array(
		'name' => esc_html__( 'Primary Sidebar', 'zoom-lite' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Zoom Footer ( Left )', 'zoom-lite' ),
		'id' => 'footer-left',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Zoom Footer ( Center )', 'zoom-lite' ),
		'id' => 'footer-center',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Zoom Footer ( Right )', 'zoom-lite' ),
		'id' => 'footer-right',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
}
add_action( 'widgets_init', 'zoom_theme_widgets_init' );